@@ -4,8 +4,9 @@ import atexit
 import sys
 import traceback
 
+from PyQt5.sip import delete
 from PyQt5.QtWidgets import QApplication
-import sip
+
 
 # Hold on to QAPP reference to avoid garbage collection
 _QAPP = QApplication.instance()
@@ -18,7 +19,7 @@ def cleanup_qapp_ref():
     """
     global _QAPP
     if _QAPP is not None:
-        sip.delete(_QAPP)
+        delete(_QAPP)
     del _QAPP
 
 
