@@ -3,10 +3,10 @@
 from enum import Enum
 
 
-class ExitState(Enum):
+class ExitState(str, Enum):
     """
     An enum that is used to specify the outcome of testing a widget.
     """
-    Success = 0
-    Warning = 1
-    Error = 2
+    Success = "Success"
+    Warning = "Warning"
+    Error = "Error"
